@@ -6,9 +6,7 @@ test_that("correctRounding works",{
    R <- editmatrix(c("a == 1"))
    dat <- data.frame(a=2)
    sol <- correctRounding(R,dat)
-   print(sol$corrected)
    expect_equivalent(sol$corrected[1,], data.frame(a=1))
-   #print(sol)
 })
 
 
@@ -16,9 +14,7 @@ test_that("correctRounding with fixate works",{
    R <- editmatrix(c("a + b == 2"))
    dat <- data.frame(a=2,b=1)
    sol <- correctRounding(R,dat, fixate="b")
-   print(sol$corrected)
    expect_equivalent(sol$corrected[1,], data.frame(a=1,b=1))
-   #print(sol)
 })
 
 test_that("correctRounding with Q works",{
@@ -26,9 +22,7 @@ test_that("correctRounding with Q works",{
    R <- editmatrix(c("a + b == 2", "b>0"))
    dat <- data.frame(a=2,b=1)
    sol <- correctRounding(R,dat)
-   print(sol$corrected)
    expect_equivalent(sol$corrected[1,], data.frame(a=1,b=1))
-   #print(sol)
 })
 
 test_that("correctRounding works with Scholtus 2008 example",{
@@ -53,6 +47,5 @@ test_that("correctRounding works with Scholtus 2008 example",{
                     , x11=-13
                     )
    sol <- correctRounding(E,dat)
-   #print(sol)
    expect_equal(as.character(sol$status$status), "corrected")
 })
\ No newline at end of file
